==> jc-1.4.0.tar.gz: javax/swing/JPopupMenu__24AccessibleJPopupMenu.h <==
// public class javax.swing.JPopupMenu$AccessibleJPopupMenu

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 91d666abd6905572 javax_swing_JPopupMenu__24AccessibleJPopupMenu

// header file dependencies
// @dep_header javax_swing_JComponent__24AccessibleJComponent

#include "javax/swing/JComponent__24AccessibleJComponent.h"

#ifndef _JC_javax_swing_JPopupMenu__24AccessibleJPopupMenu_H_
#define _JC_javax_swing_JPopupMenu__24AccessibleJPopupMenu_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_JPopupMenu$object;

// Typedefs
typedef struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$sub_refs	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$sub_refs;
typedef struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$sub_nonrefs	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$sub_nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$refs	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$refs;
typedef struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$nonrefs	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$object	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$object;

typedef struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$fields_struct	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$fields_struct;
typedef const struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vmethods	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vmethods;
typedef const struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vtable	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vtable;
typedef const struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vtype	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vtype;

// Class fields structure
struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$fields_struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$class_fields;

// Constructors
extern void _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$method$_init$83d0e0054d3484d1(_jc_env *, struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$object *, struct _jc_javax_swing_JPopupMenu$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$object *);
};

// Vtable
struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vmethods	javax_swing_JPopupMenu__24AccessibleJPopupMenu;
};

// Vtype
struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vtype {
	_jc_type			type;
	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$sub_refs {
	struct _jc_javax_swing_JPopupMenu$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$refs {
    _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$sub_refs	javax_swing_JPopupMenu__24AccessibleJPopupMenu;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$sub_nonrefs	javax_swing_JPopupMenu__24AccessibleJPopupMenu;
};

// Object instance structure
struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$object {
	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vtype	*vtype;
	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vtype _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JPopupMenu__24AccessibleJPopupMenu, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$class_object;

#endif	/* _JC_javax_swing_JPopupMenu__24AccessibleJPopupMenu_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JPopupMenu__24AccessibleJPopupMenu.h <==
// public class javax.swing.JPopupMenu$AccessibleJPopupMenu

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 91d666abd6905572 javax_swing_JPopupMenu__24AccessibleJPopupMenu

// header file dependencies
// @dep_header javax_swing_JComponent__24AccessibleJComponent

#include "javax/swing/JComponent__24AccessibleJComponent.h"

#ifndef _JC_javax_swing_JPopupMenu__24AccessibleJPopupMenu_H_
#define _JC_javax_swing_JPopupMenu__24AccessibleJPopupMenu_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_JPopupMenu$object;

// Typedefs
typedef struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$sub_refs	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$sub_refs;
typedef struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$sub_nonrefs	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$sub_nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$refs	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$refs;
typedef struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$nonrefs	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$object	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$object;

typedef struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$fields_struct	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$fields_struct;
typedef const struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vmethods	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vmethods;
typedef const struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vtable	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vtable;
typedef const struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vtype	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vtype;

// Class fields structure
struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$fields_struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$class_fields;

// Constructors
extern void _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$method$_init$83d0e0054d3484d1(_jc_env *, struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$object *, struct _jc_javax_swing_JPopupMenu$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vmethods	javax_swing_JPopupMenu__24AccessibleJPopupMenu;
};

// Vtype
struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vtype {
	_jc_type			type;
	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$sub_refs {
	struct _jc_javax_swing_JPopupMenu$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$refs {
    _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$sub_refs	javax_swing_JPopupMenu__24AccessibleJPopupMenu;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$sub_nonrefs	javax_swing_JPopupMenu__24AccessibleJPopupMenu;
};

// Object instance structure
struct _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$object {
	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vtype	*vtype;
	_jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$vtype _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JPopupMenu__24AccessibleJPopupMenu, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JPopupMenu__24AccessibleJPopupMenu$class_object;

#endif	/* _JC_javax_swing_JPopupMenu__24AccessibleJPopupMenu_H_ */
